import 'package:auto_route/auto_route.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/widget_export.dart';
import '../../detail/facility_detail_page.dart';
import 'facility_history_view_model.dart';
import 'item_facility_history.dart';


@RoutePage()
class FacilityHistoryScreen extends HookConsumerWidget {
  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final viewModel = ref.read(facilityHistoryViewModelProvider.notifier);
    final state = ref.watch(facilityHistoryViewModelProvider);

    useEffect(() {
      // 组件挂载时执行 - 执行接口请求
      Future.microtask(() => viewModel.fetchList());
      return () {
        // 组件卸载时执行
      };
    }, []);

    return SizedBox(
      width: double.infinity,
      height: double.infinity,
      child: EasyRefresh(
        controller: viewModel.refreshController,
        onRefresh: viewModel.onRefresh,
        onLoad: viewModel.loadMore,
        child: LoadStateLayout(
          state: state.loadingState,
          errorMessage: state.errorMessage,
          errorRetry: () {
            viewModel.retryRequest();
          },
          successSliverWidget: [
            SliverList(
                delegate: SliverChildBuilderDelegate((context, index) {
                    return FacilityHistoryItem(index: index, item: state.datas[index]).onTap((){
                      FacilityDetailPage.startInstance(context: context,bookingId: state.datas[index].booking?.id);
                    });
                  },
                  childCount: state.datas.length,
                )),
          ],
        ),
      ).marginOnly(top: 5, bottom: 5),
    );
  }
}
