import 'package:domain/constants/api_constants.dart';
import 'package:domain/entity/rewards_category_entity.dart';
import 'package:domain/entity/rewards_home_entity.dart';
import 'package:domain/entity/rewards_home_tes_entity.dart';
import 'package:domain/entity/rewards_home_test_entity.dart';
import 'package:domain/entity/rewards_home_tx_entity.dart';
import 'package:domain/entity/server_time.dart';
import 'package:domain/entity/text_kon_entity.dart';
import 'package:plugin_platform/platform_export.dart';
import 'package:plugin_platform/http/dio_engine.dart';
import 'package:plugin_platform/http/http_result.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:shared/utils/util.dart';

import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:plugin_basic/provider/http_provider/http_provider.dart';

import './rewards_home_state.dart';
part 'rewards_home_repository.g.dart';

@Riverpod(keepAlive: true)
RewardsHomeRepository rewardsHomeRepository(Ref ref) {
  final dioEngine = ref.watch(dioEngineProvider);
  return RewardsHomeRepository(dioEngine: dioEngine);
}

/*
 * 数据仓库
 */
class RewardsHomeRepository {
  DioEngine dioEngine;

  RewardsHomeRepository({required this.dioEngine});

  Future<HttpResult<Object>> fetchPropertyNewsList(
    Map<String, dynamic>? data, {
    CancelToken? cancelToken,
  }) async {
    Map<String, dynamic> params = {};

    params = data!;

    Map<String, String> headers = {};

    headers["Content-Type"] = "application/x-www-form-urlencoded";
    headers["Accept"] = "application/x.yyjobs-api.v1+json";

    final result = await dioEngine.requestNetResult(
      // ApiConstants.apiServerTime, // api 地址
      '/api/v1/user/reward/reward/home', // api 地址
      params: params,
      headers: headers,
      method: HttpMethod.GET,
      isShowLoadingDialog: false, //是否展示默认的Loading弹窗
      networkDebounce: true, //是否防抖防止重复请求
      cancelToken: cancelToken,
    );

    Log.d("------请求返回的result--$result--------");
    //根据返回的结果，封装原始数据为Bean/Entity对象
    if (result.isSuccess) {
      //重新赋值data或list
      // result.setList(result.getListJson());
      final json = result.getListJson();
      Log.d("------json--$json--------");
      List<RewardsHomeTxEntity> data =
          json?.map((item) => RewardsHomeTxEntity.fromJson(item)).toList() ??
              [];
      // var data = RewardsHomeTesEntity.fromJson(json);
      Log.d("------data--$data--------");
      //重新赋值data或list
      return result.convert(list: data);
    }
    return result.convert();
  }

  Future<HttpResult<Object>> fetchCategory(
    Map<String, dynamic>? data, {
    CancelToken? cancelToken,
  }) async {
    Map<String, dynamic> params = {};

    params = data!;

    Map<String, String> headers = {};

    headers["Content-Type"] = "application/x-www-form-urlencoded";
    headers["Accept"] = "application/x.yyjobs-api.v1+json";

    final result = await dioEngine.requestNetResult(
      // ApiConstants.apiServerTime, // api 地址
      '/api/v1/user/reward/category/index', // api 地址
      params: params,
      headers: headers,
      method: HttpMethod.GET,
      isShowLoadingDialog: false, //是否展示默认的Loading弹窗
      networkDebounce: true, //是否防抖防止重复请求
      cancelToken: cancelToken,
    );

    Log.d("------请求返回的result--$result--------");
    //根据返回的结果，封装原始数据为Bean/Entity对象
    if (result.isSuccess) {
      //重新赋值data或list
      final json = result.getListJson();
      Log.d("------json--$json--------");
      List<RewardsCategoryEntity> data =
          json?.map((item) => RewardsCategoryEntity.fromJson(item)).toList() ??
              [];
      // var data = RewardsHomeTesEntity.fromJson(json);
      Log.d("------data--$data--------");
      //重新赋值data或list
      return result.convert(list: data);
    }
    return result.convert();
  }
}
