
import 'package:cpt_services/components/chooseAirConditionContent_vm.dart';
import 'package:cpt_services/components/chooseHouseCleanContent_vm.dart';
import 'package:cpt_services/components/chooseVisitTimeContent.dart';
import 'package:cpt_services/components/chooseVisitTimeContent_vm.dart';
import 'package:cpt_services/components/chooseVisitTimeTitle.dart';
import 'package:cs_resources/generated/assets.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:domain/entity/garage_sale_rent_entity.dart';
import 'package:domain/entity/newsfeed_detail_entity.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:plugin_platform/engine/dialog/dialog_engine.dart';
import 'package:plugin_platform/engine/toast/toast_engine.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/ext_dart.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:widgets/dialog/dialog_content_wrap.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/widget_export.dart';

import '../../../components/chooseHouseCleanContent.dart';
import '../../../components/chooseHouseCleanTitle.dart';
import '../../../components/chooseVisitTimeBottomFooter.dart';
import '../../../constants_services.dart';
import '../../../respository/services_respository.dart';
import '../../../router/page/services_page_router.dart';
import '../service_pay_success/service_pay_success_page.dart';
import 'service_order_confirm_state.dart';

part 'service_order_confirm_vm.g.dart';


final _chooseVisitTimeDialogGlobalKey = GlobalKey<DialogContentWrapState>();

@riverpod
class ServiceOrderConfirmVm extends _$ServiceOrderConfirmVm {
  late ServicesRespository servicesRespositoryInstance;
  bool _needShowPlaceholder = false; //是否展示LoadingView
  int _page = 1;  // 当前页
  int _limit = 10; // 每页数量
  int _count = 0; // 总条数

  int _detailId = 0;
  int _detailServiceTypeCode = 0;

  // Refresh 控制器
  final EasyRefreshController refreshController = EasyRefreshController(
    controlFinishRefresh: true,  //允许刷新
    controlFinishLoad: true,   //允许加载
  );

  ServiceOrderConfirmState initState() {
    return ServiceOrderConfirmState(
      datas: {}
    );
  }

  @override
  ServiceOrderConfirmState build(){
    // 引入数据仓库
    // servicesRespositoryInstance = ref.read(commonGarageRespositoryProvider);
    final state = initState();
    Log.d("--------------------------build---------------------");

    return state;
  }


  //刷新页面状态
  void changeLoadingState(LoadState loadState, String? errorMsg) {
    state = state.copyWith(
        loadingState: loadState,
        errorMessage: errorMsg
    );
  }


  setInitPageData({required int id, required int serviceTypeCode}){
    _detailId = id;
    _detailServiceTypeCode = serviceTypeCode;
  }
  // 初始化页面数据
  initPageData({detailId, detailServiceTypeCode}) {
    _detailId = detailId??_detailId;
    _detailServiceTypeCode = detailServiceTypeCode??_detailServiceTypeCode;
    Log.d("--------------------------initPageData---------------------");
    changeLoadingState(LoadState.State_Success, null);
    setConfirmOrderTotalPrice(null);
  }

  // 上拉加载 更多
  Future loadMore() async {
    Log.d("----home_service_vm-----loadMore");
    _page++;
    getListData();
  }


  // 下拉刷新
  Future onRefresh() async {
    // 当前pageView 页面正处于显示状态
    Log.d("----forsale_vm-----onRefresh ");
    // await Future.delayed(const Duration(seconds: 2));
    _page = 1;
    getListData();
  }


  // 手动进行刷新
  Future triggerRefresh() async {
    Log.d("trggerRefresh");
    refreshController.callRefresh();
  }

  // 手动进行刷新
  Future directRefresh() async {
    state = state.copyWith(datas:null);
    // 注意：由于 nestedscrollview 嵌套easyfresh 组件  refreshController.callRefresh() 自动刷新只能滚动顶部但是不会触发下拉刷新，这里调用是 用到了将其滚动到顶部的作用，进而刷新操作主动掉接口
    // https://github.com/xuelongqy/flutter_easy_refresh/issues/692
    refreshController.callRefresh();
    refreshController.resetFooter();
    _page = 1;
    _needShowPlaceholder = true;
    getListData();
  }


  // 重试请求
  Future retryRequest() async {
    _page = 1;
    _needShowPlaceholder = true;
    getListData();
  }


  // 获取list 列表数据
  Future getListData<T>({bool? isLoadMore}) async {
    if (_needShowPlaceholder) {
      changeLoadingState(LoadState.State_Loading, null);
    }

    List<Map<String, dynamic>> list = [
      {
        'id':1,
        'service_type': 0,  // 0 房屋保洁 1 空调保洁  2 维修
        'cover_img':  'https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500',
        'resources': ['https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500'],
        'title': 'House Cleaning Services',
        'duration': 'Daily cleaning for 2 hours',
        'totalPrice': 66,
        'visit_time': '14 0ct 2024 15:00',
        'order_time': '13 0ct 2024 12:00',
        'status_text': 'In Progress',
        'status_code': 0,
        'company_name': 'HONG YE GROUP PTE LTD',
      },
      {
        'id':2,
        'service_type': 0,  // 0 房屋保洁 1 空调保洁  2 维修
        'cover_img':  'https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500',
        'resources': ['https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500'],
        'title': 'House Cleaning Services',
        'duration': 'Daily cleaning for 2 hours',
        'totalPrice': 66,
        'visit_time': '14 0ct 2024 15:00',
        'order_time': '13 0ct 2024 12:00',
        'status_text': 'In Progress',
        'status_code': 1,
        'company_name': 'HONG YE GROUP PTE LTD',
      },
      {
        'id':3,
        'service_type': 0,  // 0 房屋保洁 1 空调保洁  2 维修
        'cover_img':  'https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500',
        'resources': ['https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500'],
        'title': 'House Cleaning Services',
        'duration': 'Daily cleaning for 2 hours',
        'totalPrice': 66,
        'visit_time': '14 0ct 2024 15:00',
        'order_time': '13 0ct 2024 12:00',
        'status_text': 'In Progress',
        'status_code': 1,
        'company_name': 'HONG YE GROUP PTE LTD',
      },
    ];
    handlerResultData(true, list:list);

    // try {
    //   //请求网络
    //   Map<String, dynamic>  params = {
    //     "type": 1,  // 类型(1=Sale,2=Rent)
    //     "category_id": _queryParams['category_id'],
    //     "keyword": _queryParams['keyword'],
    //     "page": _page,
    //     "limit": _limit,
    //   };
    //   Log.d("请求参数------$params");
    //   final result = await servicesRespositoryInstance.fetchGarageDataList(params);
    //   //校验成功失败
    //   if (result.isSuccess) {
    //     // handlerResultList((result.data as GarageSaleRentEntity).list as List<GarageSaleRentList>, isLoadMore ?? false);
    //   } else {
    //     String errorMessage = result.errorMsg!;
    //     changeLoadingState(LoadState.State_Error, errorMessage);
    //     ToastEngine.show(result.errorMsg ?? "Network Load Error");
    //   }
    // } catch (e) {
    //   ToastEngine.show("Error: $e");
    // }

    // 最后赋值
    _needShowPlaceholder = false;

  }

  handlerResultData(bool isList, {List<Map<String, dynamic>>? list, dynamic? data}){
    Future.delayed(const Duration(seconds: 1)).then((value) {
      if(isList){
        // list 数据模式
        // if(list != null && list.isNotEmpty){
        //   if(_page == 1){
        //     state.list.clear();
        //     state.list!.addAll(list);
        //     refreshController.finishRefresh();
        //     changeLoadingState(LoadState.State_Success, null);
        //   }else {
        //     final allList = state.list;
        //     allList!.addAll(list);
        //     state = state.copyWith(list: allList);
        //     refreshController.finishLoad();
        //   }
        // }else {
        //   if(_page == 1){
        //     state.list.clear();
        //     changeLoadingState(LoadState.State_Empty, null);
        //     refreshController.finishRefresh();
        //   }else {
        //     refreshController.finishLoad(IndicatorResult.noMore);
        //   }
        // }
      }else {
        // 单个数据模式
        if(data!=null){
          if(_page == 1){
            refreshController.finishRefresh();
          }else{
            refreshController.finishLoad();
          }
          changeLoadingState(LoadState.State_Success, null);
        }else {
          if(_page == 1){
            refreshController.finishRefresh();
          }else{
            refreshController.finishLoad();
          }
          changeLoadingState(LoadState.State_Empty, null);
        }
      }
    });
  }


  handlerClickVisitTime(BuildContext context){
    // ToastEngine.show("Visit Time");
    handlerShowChooseVisitTimeDialog(context);
  }

  // 显示 选择空调型号和数量的弹框
  handlerShowChooseVisitTimeDialog(BuildContext context) async{
    // 定时器
    LoadState dialogState = LoadState.State_Loading;

    DialogEngine.show(
        tag: "chooseAirConditionClean",
        position: DialogPosition.bottom,
        widget: DialogContentWrap(
          key: _chooseVisitTimeDialogGlobalKey,
          loadingState: dialogState,
          maxHeight: 480.0,
          dialogWidth: context.screenSize.width,
          isShowConfirmBtn: false,
          isShowCancelBtn: false,
          title: "",
          bottomBtnRadius:0,
          bottomBtnSpace: 0,
          topLeftRadius: 20.0,
          topRightRadius: 20.0,
          // bottomBtnSectionPadding: EdgeInsets.only(left: 20, right: 20, bottom: 20,top: 20),
          yesBtnBg: context.appColors.redDefault,
          noBtnBg: context.appColors.grayBgE9,
          confirmTxt: "Confirm",
          cancelTxt: "Cancel",
          // yesBtnTextStyle: TextStyle(
          //   color: context.appColors.textWhite,
          //   fontSize: 17,
          //   fontWeight: FontWeight.w400
          // ),
          // noBtnTextStyle: TextStyle(
          //   color: context.appColors.textBlack,
          //   fontSize: 17,
          //   fontWeight: FontWeight.w400
          // ),
          confirmAction: chooseVisitTimeConfirmFn,
          cancelAction: chooseVisitTimeCancelFn,
          titleBuilder: (context) {
            return buildChooseVisitTimeTitle(context);
          },
          messageBuilder: (context) {
            return buildChooseVisitTimeContent(context);
          },
          bottomFooterBuilder: (context){
            return  buildChooseVisitTimeBottomFooter(context);
          },
        )
    );

    await Future.delayed(Duration(milliseconds: 1000));

    _chooseVisitTimeDialogGlobalKey.currentState?.changeDialogLoadingState(LoadState.State_Success);
  }

  chooseVisitTimeConfirmFn(){
    Log.d("点击了确定");
    // 跳转到 订单确认页面
    // appRouter.push(ServiceOrderConfirmPageRoute(id: _detailId, serviceTypeCode: _detailServiceTypeCode));
  }

  chooseVisitTimeCancelFn(){
    Log.d("点击了取消");
  }

  Widget buildChooseVisitTimeTitle(BuildContext context){
    return ChooseVisitTimeTitle(id: 0, serviceTypeCode: 0);
  }

  Widget buildChooseVisitTimeContent(BuildContext context){
    return ChooseVisitTimeContent(id: 0, serviceTypeCode: 0,);
  }

  Widget buildChooseVisitTimeBottomFooter(BuildContext context){
    return ChooseVisitTimeBottomFooter(id: 0, serviceTypeCode: 0,);
  }

  // 关闭visitTime 选择的弹框
  handlerHideVisitTimeDialog(){
    DialogEngine.dismiss(tag: 'chooseAirConditionClean');
  }

  // 去支付
  handlerClickPayNow(BuildContext context, {int? id, int? serviceTypeCode}){
    ToastEngine.show("Pay Now");
    // 去支付成功页面
    ServicePaySuccessPage.startInstance(id: 0, serviceTypeCode: 0);
  }

  setConfirmOrderTotalPrice(BuildContext? context){
    final visitTimeTotalPrice = ref.read(chooseVisitTimeContentVmProvider).totalPrice?? 0.0;
    final airConditionTotalPrice = ref.read(chooseAirConditionContentVmProvider).totalPrice?? 0.0 ;
    final houseCleaningTotalPrice = ref.read(chooseHouseCleanContentVmProvider).totalPrice?? 0.0;
    final totalPrice = visitTimeTotalPrice.toDouble() + airConditionTotalPrice.toDouble() + houseCleaningTotalPrice.toDouble();
    // if( _detailServiceTypeCode == servicesConstants.servicesType['houseCleaning'] ){
    //
    // }else if(_detailServiceTypeCode == servicesConstants.servicesType['airConditioner']){
    //
    // }else {
    //
    // }
    state = state.copyWith(
        totalPrice: totalPrice
    );
  }
}